@@ -1,4 +1,4 @@
-class AWSCoreException(Exception):
+class CoreException(Exception):
     ERROR_MESSAGE = 'A generic error has occurred'
 
     def __init__(self, *args, **kwargs):
@@ -13,6 +13,22 @@ class AWSCoreException(Exception):
 # https://github.com/boto/botocore/blob/develop/botocore/exceptions.py
 
 
+class APIException(CoreException):
+    ERROR_MESSAGE = 'A generic API error occurred'
+
+
+class NotAuthorizedException(APIException):
+    ERROR_MESSAGE = 'Client is not authorized to take action'
+
+
+class CookieDecodingError(APIException):
+    ERROR_MESSAGE = 'Error while decoding binary cookies'
+
+
+class AWSCoreException(CoreException):
+    ERROR_MESSAGE = 'A generic AWS error occurred'
+
+
 class CognitoException(AWSCoreException):
     ERROR_MESSAGE = 'An error occurred while attempting to access Cognito'
 
